@@ -749,7 +749,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         if not member.subnet_id:
                             member.subnet_id = loadbalancer.vip_subnet_id
                         status_member = self._ovn_helper.member_create(
-                            [self._get_member_request_info(member)])
+                            self._get_member_request_info(member))
                         status[constants.MEMBERS].append(
                             status_member[constants.MEMBERS][0])
                     if pool.healthmonitor is not None and not isinstance(
@@ -819,7 +819,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                                         'subnet_id': ovn_mb_info[2],
                                     }
                                     self._ovn_helper.member_delete(
-                                        [mb_delete_info])
+                                        mb_delete_info)
 
                                     mb_delete_dvr_info = {
                                         'id': ovn_mb_info[3],
@@ -830,7 +830,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                                             ovn_const.REQ_INFO_MEMBER_DELETED
                                     }
                                     self._ovn_helper.handle_member_dvr(
-                                        [mb_delete_dvr_info])
+                                        mb_delete_dvr_info)
                         # Check health monitor
                         if pool.healthmonitor is not None and not isinstance(
                                 pool.healthmonitor, o_datamodels.UnsetType):
@@ -866,7 +866,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         if fips:
             neutron_fip = fips[0].floating_ip_address
             if not vip_lsp:
-                LOG.warn(
+                LOG.warning(
                     "Logic Switch Port not found for port "
                     f"{loadbalancer.vip_port_id}. "
                     "Skip sync FIP for loadbalancer "
@@ -875,7 +875,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                     "first to sync OVN DB with Neutron DB.")
                 return
             if lsp_fip != neutron_fip:
-                LOG.warn(
+                LOG.warning(
                     "Floating IP not consistent between Logic Switch "
                     f"Port and Neutron. Found FIP {lsp_fip} "
                     f"in LSP {vip_lsp.name}, but we have {neutron_fip} from "
@@ -888,10 +888,10 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 vip_lp=vip_lsp, fip=lsp_fip,
                 action=ovn_const.REQ_INFO_ACTION_SYNC)
         else:
-            LOG.warn("Floating IP not found for loadbalancer "
-                     f"{loadbalancer.loadbalancer_id}")
+            LOG.warning("Floating IP not found for loadbalancer "
+                        f"{loadbalancer.loadbalancer_id}")
             if lsp_fip:
-                LOG.warn(
+                LOG.warning(
                     "Floating IP not consistent between Logic Switch "
                     f"Port and Neutron. Found FIP {lsp_fip} configured "
                     f"in LSP {vip_lsp.name}, but no FIP configured from "
